@@ -1,7 +1,8 @@
 import pytest  # noqa
 import six
+import tippo
 
-from basicco.explicit_hash import ExplicitHash, ExplicitHashMeta
+from basicco.explicit_hash import ExplicitHash, ExplicitHashMeta, set_to_none
 
 
 def test_class():
@@ -30,5 +31,17 @@ def test_force_explicit_hash_declaration():
     assert SubClass
 
 
+def test_set_to_none():
+    class Class(object):
+        @set_to_none
+        def __hash__(self):
+            error = "not hashable"
+            raise TypeError(error)
+
+    assert not issubclass(Class, tippo.Hashable)
+    assert not isinstance(Class(), tippo.Hashable)
+    assert Class.__hash__ is None
+
+
 if __name__ == "__main__":
     pytest.main()
